@@ -1,31 +1,15 @@
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 #   Copyright 2012 - 2013   David Sommerseth <davids@redhat.com>
 #
-#   This program is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
-#
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License along
-#   with this program; if not, write to the Free Software Foundation, Inc.,
-#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-#   For the avoidance of doubt the "preferred form" of this code is one which
-#   is in an open unpatent encumbered format. Where cryptographic key signing
-#   forms part of the process of creating an executable the information
-#   including keys needed to generate an equivalently functional executable
-#   are deemed to be part of the source code.
-#
 
+import time
+from datetime import datetime
+import threading
+import argparse
+import libxml2
 from rteval.Log import Log
 from rteval.rtevalConfig import rtevalCfgSection
-from datetime import datetime
-import time, libxml2, threading, optparse
 
 __all__ = ["rtevalRuntimeError", "rtevalModulePrototype", "ModuleContainer", "RtEvalModules"]
 
@@ -38,7 +22,7 @@ class rtevalRuntimeError(RuntimeError):
 
 
 class rtevalModulePrototype(threading.Thread):
-    "Prototype class for rteval modules - must be inherited by the real module"
+    """ Prototype rteval modules class - to be inherited by the real module """
 
     def __init__(self, modtype, name, logger=None):
         if logger and not isinstance(logger, Log):
@@ -55,68 +39,80 @@ class rtevalModulePrototype(threading.Thread):
                          "stop": threading.Event(),
                          "finished": threading.Event()}
         self._donotrun = False
+        self._exclusive = False
         self.__timestamps = {}
         self.__sleeptime = 2.0
 
 
     def _log(self, logtype, msg):
-        "Common log function for rteval modules"
+        """ Common log function for rteval modules """
         if self.__logger:
             self.__logger.log(logtype, "[%s] %s" % (self._name, msg))
 
 
     def isReady(self):
-        "Returns a boolean if the module is ready to run"
+        """ Returns a boolean if the module is ready to run """
         if self._donotrun:
             return True
         return self.__ready
 
 
+    def is_exclusive(self):
+        """ Returns true if this workload should run alone """
+        return self._exclusive
+
+
+    def set_donotrun(self):
+        """ set a module's donotrun field to True """
+        self._donotrun = True
+
+
     def _setReady(self, state=True):
-        "Sets the ready flag for the module"
+        """ Sets the ready flag for the module """
         self.__ready = state
 
 
     def hadRuntimeError(self):
-        "Returns a boolean if the module had a RuntimeError"
+        """ Returns a boolean if the module had a RuntimeError """
         return self.__runtimeError
 
 
     def _setRuntimeError(self, state=True):
-        "Sets the runtimeError flag for the module"
+        """ Sets the runtimeError flag for the module """
         self.__runtimeError = state
 
 
     def setStart(self):
-        "Sets the start event state"
+        """ Sets the start event state """
         self.__events["start"].set()
         self.__timestamps["start_set"] = datetime.now()
 
 
     def shouldStart(self):
-        "Returns the start event state - indicating the module can start"
+        """Returns the start event state - indicating the module can start """
         return self.__events["start"].isSet()
 
 
     def setStop(self):
-        "Sets the stop event state"
+        """ Sets the stop event state """
         self.__events["stop"].set()
         self.__timestamps["stop_set"] = datetime.now()
 
 
     def shouldStop(self):
-        "Returns the stop event state - indicating the module should stop"
+        """ Returns the stop event state - indicating the module should stop """
         return self.__events["stop"].isSet()
 
 
     def _setFinished(self):
-        "Sets the finished event state - indicating the module has completed"
+        """ Sets the finished event state - indicating the module has completed
+        """
         self.__events["finished"].set()
         self.__timestamps["finished_set"] = datetime.now()
 
 
-    def WaitForCompletion(self, wtime = None):
-        "Blocks until the module has completed its workload"
+    def WaitForCompletion(self, wtime=None):
+        """ Blocks until the module has completed its workload """
         if not self.shouldStart():
             # If it hasn't been started yet, nothing to wait for
             return None
@@ -124,32 +120,42 @@ class rtevalModulePrototype(threading.Thread):
 
 
     def _WorkloadSetup(self):
-        "Required module method, which purpose is to do the initial workload setup, preparing for _WorkloadBuild()"
+        """ Required module method, which purpose is to do the initial workload
+        setup, preparing for _WorkloadBuild()
+        """
         raise NotImplementedError("_WorkloadSetup() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadBuild(self):
-        "Required module method, which purpose is to compile additional code needed for the worklaod"
+        """ Required module method, which purpose is to compile additional code
+        needed for the worklaod
+        """
         raise NotImplementedError("_WorkloadBuild() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadPrepare(self):
-        "Required module method, which will initialise and prepare the workload just before it is about to start"
+        """ Required module method, which will initialise and prepare the
+        workload just before it is about to start
+        """
         raise NotImplementedError("_WorkloadPrepare() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadTask(self):
-        "Required module method, which kicks off the workload"
+        """ Required module method, which kicks off the workload """
         raise NotImplementedError("_WorkloadTask() method must be implemented in the %s module" % self._name)
 
 
     def WorkloadAlive(self):
-        "Required module method, which should return True if the workload is still alive"
+        """ Required module method, which should return True if the workload is
+        still alive
+        """
         raise NotImplementedError("WorkloadAlive() method must be implemented in the %s module" % self._name)
 
 
     def _WorkloadCleanup(self):
-        "Required module method, which will be run after the _WorkloadTask() has completed or been aborted by the 'stop event flag'"
+        """ Required module method, which will be run after the _WorkloadTask()
+        has completed or been aborted by the 'stop event flag'
+        """
         raise NotImplementedError("_WorkloadCleanup() method must be implemented in the %s module" % self._name)
 
 
@@ -189,9 +195,6 @@ class rtevalModulePrototype(threading.Thread):
 
                 if self.shouldStop():
                     break
-                if not self.WorkloadAlive():
-                    self._log(Log.DEBUG, "%s workload stopped running." % self._module_type)
-                    break
                 time.sleep(self.__sleeptime)
 
             self.__timestamps["runloop_stop"] = datetime.now()
@@ -203,7 +206,9 @@ class rtevalModulePrototype(threading.Thread):
 
 
     def MakeReport(self):
-        "required module method, needs to return an libxml2.xmlNode object with the the results from running"
+        """ required module method, needs to return an libxml2.xmlNode object
+        with the the results from running
+        """
         raise NotImplementedError("MakeReport() method must be implemented in the%s module" % self._name)
 
 
@@ -211,14 +216,14 @@ class rtevalModulePrototype(threading.Thread):
         "Return libxml2.xmlNode object with the gathered timestamps"
 
         ts_n = libxml2.newNode("timestamps")
-        for k in self.__timestamps.keys():
+        for k in list(self.__timestamps.keys()):
             ts_n.newChild(None, k, str(self.__timestamps[k]))
 
         return ts_n
 
 
 
-class ModuleContainer(object):
+class ModuleContainer:
     """The ModuleContainer keeps an overview over loaded modules and the objects it
 will instantiate.  These objects are accessed by iterating the ModuleContainer object."""
 
@@ -259,7 +264,7 @@ reference from the first import"""
             return mod
 
 
-    def ModuleInfo(self, modname, modroot = None):
+    def ModuleInfo(self, modname, modroot=None):
         """Imports a module and calls the modules' ModuleInfo() function and returns
 the information provided by the module"""
 
@@ -268,16 +273,15 @@ the information provided by the module"""
 
 
     def SetupModuleOptions(self, parser, config):
-        """Sets up a separate optptarse OptionGroup per module with its supported parameters"""
+        """Sets up a separate argparse ArgumentGroup per module with its supported parameters"""
 
-        grparser = optparse.OptionGroup(parser, "Group Options for %s modules" % self.__modtype)
-        grparser.add_option('--%s-cpulist' % self.__modtype,
+        grparser = parser.add_argument_group("Group Options for %s modules" % self.__modtype)
+        grparser.add_argument('--%s-cpulist' % self.__modtype,
                             dest='%s___cpulist' % self.__modtype, action='store', default="",
                             help='CPU list where %s modules will run' % self.__modtype,
                             metavar='LIST')
-        parser.add_option_group(grparser)
 
-        for (modname, mod) in self.__modsloaded.items():
+        for (modname, mod) in list(self.__modsloaded.items()):
             opts = mod.ModuleParameters()
             if len(opts) == 0:
                 continue
@@ -289,10 +293,10 @@ the information provided by the module"""
                 # Ignore if a section is not found
                 cfg = None
 
-            grparser = optparse.OptionGroup(parser, "Options for the %s module" % shortmod)
-            for (o, s) in opts.items():
-                descr   = s.has_key('descr') and s['descr'] or ""
-                metavar = s.has_key('metavar') and s['metavar'] or None
+            modgrparser = parser.add_argument_group("Options for the %s module" % shortmod)
+            for (o, s) in list(opts.items()):
+                descr = 'descr' in s and s['descr'] or ""
+                metavar = 'metavar' in s and s['metavar'] or None
 
                 try:
                     default = cfg and getattr(cfg, o) or None
@@ -301,20 +305,21 @@ the information provided by the module"""
                     default = None
 
                 if default is None:
-                    default = s.has_key('default') and s['default'] or None
+                    default = 'default' in s and s['default'] or None
 
 
-                grparser.add_option('--%s-%s' % (shortmod, o),
-                                    dest="%s___%s" % (shortmod, o),
-                                    action='store',
-                                    help='%s%s' % (descr,
-                                                   default and ' (default: %s)' % default or ''),
-                                    default=default,
-                                    metavar=metavar)
-            parser.add_option_group(grparser)
+                modgrparser.add_argument('--%s-%s' % (shortmod, o),
+                                         dest="%s___%s" % (shortmod, o),
+                                         action='store',
+                                         help='%s%s' % (descr,
+                                                        default and ' (default: %s)' % default or ''),
+                                         default=default,
+                                         metavar=metavar)
+
+            return grparser
 
 
-    def InstantiateModule(self, modname, modcfg, modroot = None):
+    def InstantiateModule(self, modname, modcfg, modroot=None):
         """Imports a module and instantiates an object from the modules create() function.
 The instantiated object is returned in this call"""
 
@@ -331,7 +336,7 @@ returned when a ModuleContainer object is iterated over"""
         self.__modobjects[modname] = modobj
 
 
-    def ExportModule(self, modname, modroot = None):
+    def ExportModule(self, modname, modroot=None):
         "Export module info, used to transfer an imported module to another ModuleContainer"
         if modroot is None:
             modroot = self.__modules_root
@@ -353,7 +358,7 @@ returned when a ModuleContainer object is iterated over"""
 
     def GetModulesList(self):
         "Returns a list of module names"
-        return self.__modobjects.keys()
+        return list(self.__modobjects.keys())
 
 
     def GetNamedModuleObject(self, modname):
@@ -364,33 +369,36 @@ returned when a ModuleContainer object is iterated over"""
     def __iter__(self):
         "Initiates the iterating process"
 
-        self.__iter_list = self.__modobjects.keys()
+        self.__iter_list = list(self.__modobjects.keys())
         return self
 
 
-    def next(self):
-        """Internal Python iterating method, returns the next
-module name and object to be processed"""
+    def __next__(self):
+        """ Internal Python iterating method, returns the next
+        module name and object to be processed
+        """
 
         if len(self.__iter_list) == 0:
             self.__iter_list = None
             raise StopIteration
-        else:
-            modname = self.__iter_list.pop()
-            return (modname, self.__modobjects[modname])
+        modname = self.__iter_list.pop()
+        return (modname, self.__modobjects[modname])
 
 
 
-class RtEvalModules(object):
-    """RtEvalModules should normally be inherrited by a more specific module class.
-    This class takes care of managing imported modules and have methods for starting
-    and stopping the workload these modules contains."""
+class RtEvalModules:
+    """ RtEvalModules should normally be inherrited by a more specific module
+    class.  This class takes care of managing imported modules and has methods
+    for starting and stopping the workload these modules contains.
+    """
 
     def __init__(self, config, modules_root, logger):
-        """Initialises the RtEvalModules() internal variables.  The modules_root
-argument should point at the root directory where the modules will be loaded from.
-The logger argument should point to a Log() object which will be used for logging
-and will also be given to the instantiated objects during module import."""
+        """ Initialises the RtEvalModules() internal variables.
+        The modules_root argument should point at the root directory where
+        the modules will be loaded from. The logger argument should point
+        to a Log() object which will be used for logging and will also be given
+        to the instantiated objects during module import.
+        """
 
         self._cfg = config
         self._logger = logger
@@ -405,7 +413,7 @@ and will also be given to the instantiated objects during module import."""
         "Imports a module exported by ModuleContainer::ExportModule()"
         return self.__modules.ImportModule(module)
 
-    def _InstantiateModule(self, modname, modcfg, modroot = None):
+    def _InstantiateModule(self, modname, modcfg, modroot=None):
         "Imports a module and returns an instantiated object from the module"
         return self.__modules.InstantiateModule(modname, modcfg, modroot)
 
@@ -426,7 +434,7 @@ and will also be given to the instantiated objects during module import."""
         return self.__modules.GetModulesList()
 
     def SetupModuleOptions(self, parser):
-        "Sets up optparse based option groups for the loaded modules"
+        "Sets up argparse based argument groups for the loaded modules"
         return self.__modules.SetupModuleOptions(parser, self._cfg)
 
     def GetNamedModuleObject(self, modname):
@@ -436,14 +444,24 @@ and will also be given to the instantiated objects during module import."""
 
 
     def Start(self):
-        """Prepares all the imported modules workload to start, but they will not
-start their workloads yet"""
-
+        """ Prepares all the imported modules workload to start, but they
+        will not start their workloads yet
+        """
         if self.__modules.ModulesLoaded() == 0:
             raise rtevalRuntimeError("No %s modules configured" % self._module_type)
 
         self._logger.log(Log.INFO, "Preparing %s modules" % self._module_type)
+        exclusive = 0
         for (modname, mod) in self.__modules:
+            if mod.is_exclusive() and mod.WorkloadWillRun():
+                exclusive += 1
+        for (modname, mod) in self.__modules:
+            if exclusive >= 1:
+                if exclusive != 1:
+                    msg = f"More than one exclusive load: {exclusive}"
+                    raise RuntimeError(msg)
+                if not mod.is_exclusive() and mod.WorkloadWillRun():
+                    mod.set_donotrun()
             mod.start()
             if mod.WorkloadWillRun():
                 self._logger.log(Log.DEBUG, "\t - Started %s preparations" % modname)
@@ -511,12 +529,12 @@ start their workloads yet"""
                 self._logger.log(Log.DEBUG, "\t - Stopping %s" % modname)
                 if mod.is_alive():
                     mod.join(2.0)
-            except RuntimeError, e:
+            except RuntimeError as e:
                 self._logger.log(Log.ERR, "\t\tFailed stopping %s: %s" % (modname, str(e)))
         self.__timestamps['stop'] = datetime.now()
 
 
-    def WaitForCompletion(self, wtime = None):
+    def WaitForCompletion(self, wtime=None):
         """Waits for the running modules to complete their running"""
 
         self._logger.log(Log.INFO, "Waiting for %s modules to complete" % self._module_type)
