@@ -1,3 +1,4 @@
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 #   rteval - script for evaluating platform suitability for RT Linux
 #
@@ -10,26 +11,6 @@
 #   Copyright 2009,2010   Clark Williams <williams@redhat.com>
 #   Copyright 2009,2010   David Sommerseth <davids@redhat.com>
 #
-#   This program is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
-#
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
-#
-#   For the avoidance of doubt the "preferred form" of this code is one which
-#   is in an open unpatent encumbered format. Where cryptographic key signing
-#   forms part of the process of creating an executable the information
-#   including keys needed to generate an equivalently functional executable
-#   are deemed to be part of the source code.
-#
 import os
 import sys
 import configparser
@@ -115,7 +96,7 @@ class rtevalCfgSection:
         "Simple method for dumping config when object is used as a string"
         if not self.__cfgdata:
             return "# empty"
-        return "\n".join(["%s: %s" % (k, v) for k, v in list(self.__cfgdata.items())]) + "\n"
+        return "\n".join([f"{k}: {v}" for k, v in list(self.__cfgdata.items())]) + "\n"
 
 
     def __setattr__(self, key, val):
@@ -196,7 +177,7 @@ class rtevalConfig:
 
         # get our system topology info
         self.__systopology = SysTopology()
-        print(("got system topology: %s" % self.__systopology))
+        print(f"got system topology: {self.__systopology}")
 
         # Import the default config first
         for sect, vals in list(default_config.items()):
@@ -225,7 +206,7 @@ class rtevalConfig:
         "Simple method for dumping config when object is used as a string"
         ret = ""
         for sect in list(self.__config_data.keys()):
-            ret += "[%s]\n%s\n" % (sect, str(self.__config_data[sect]))
+            ret += f"[{sect}]\n{str(self.__config_data[sect])}\n"
         return ret
 
 
@@ -240,7 +221,7 @@ class rtevalConfig:
         for f in ('rteval.conf', '/etc/rteval.conf'):
             p = os.path.abspath(f)
             if os.path.exists(p):
-                self.__info("found config file %s" % p)
+                self.__info(f"found config file {p}")
                 return p
         raise RuntimeError("Unable to find configfile")
 
@@ -258,7 +239,7 @@ class rtevalConfig:
             # Don't try to reread this file if it's already been parsed
             return
 
-        self.__info("reading config file %s" % cfgfile)
+        self.__info(f"reading config file {cfgfile}")
         ini = configparser.ConfigParser()
         ini.optionxform = str
         ini.read(cfgfile)
@@ -286,12 +267,12 @@ class rtevalConfig:
         return self.__config_files.__contains__(fname)
 
 
-    def UpdateFromOptionParser(self, parser):
+    def UpdateFromOptionParser(self, cmd_opts):
         "Parse through the command line options and update the appropriate config settings"
 
         last_sect = None
-        for sk, v in sorted(vars(parser.values).items()):
-            # optparse key template: {sectionname}___{key}
+        for sk, v in sorted(vars(cmd_opts).items()):
+            # argparse key template: {sectionname}___{key}
             k = sk.split('___')
             if k[0] != last_sect:
                 # If the section name changed, retrieve the section variables
@@ -321,7 +302,7 @@ class rtevalConfig:
             # Return a new object with config settings of a given section
             return self.__config_data[section]
         except KeyError:
-            raise KeyError("The section '%s' does not exist in the config file" % section)
+            raise KeyError(f"The section '{section}' does not exist in the config file")
 
 
 def unit_test(rootdir):
