@@ -1,3 +1,4 @@
+-- SPDX-License-Identifier: GPL-2.0-or-later
 -- Create rteval database users
 --
 CREATE USER rtevxmlrpc NOSUPERUSER ENCRYPTED PASSWORD 'rtevaldb';
@@ -9,20 +10,8 @@ CREATE DATABASE rteval ENCODING 'utf-8';
 
 \c rteval
 
--- TABLE: rteval_info
--- Contains information the current rteval XML-RPC and parser installation
---
-    CREATE TABLE rteval_info (
-       key    varchar(32) NOT NULL,
-       value  TEXT NOT NULL,
-       rtiid  SERIAL,
-       PRIMARY KEY(rtiid)
-    );
-    GRANT SELECT ON rteval_info TO rtevparser;
-    INSERT INTO rteval_info (key, value) VALUES ('sql_schema_ver','1.5');
-
 -- Enable plpgsql.  It is expected that this PL/pgSQL is available.
-    CREATE LANGUAGE 'plpgsql';
+CREATE LANGUAGE 'plpgsql';
 
 -- FUNCTION: trgfnc_submqueue_notify
 -- Trigger function which is called on INSERT queries to the submissionqueue table.
@@ -87,7 +76,7 @@ CREATE DATABASE rteval ENCODING 'utf-8';
    CREATE TABLE systems_hostname (
         syskey        INTEGER REFERENCES systems(syskey) NOT NULL,
         hostname      VARCHAR(256) NOT NULL,
-        ipaddr        cidr
+        ipaddr        cidr      
     ) WITH OIDS;
     CREATE INDEX systems_hostname_syskey ON systems_hostname(syskey);
     CREATE INDEX systems_hostname_hostname ON systems_hostname(hostname);
@@ -106,7 +95,6 @@ CREATE DATABASE rteval ENCODING 'utf-8';
         kernel_ver      VARCHAR(32) NOT NULL,
         kernel_rt       BOOLEAN NOT NULL,
         arch            VARCHAR(12) NOT NULL,
-	distro		VARCHAR(64),
         run_start       TIMESTAMP WITH TIME ZONE NOT NULL,
         run_duration    INTEGER NOT NULL,
         load_avg        REAL NOT NULL,
@@ -127,13 +115,8 @@ CREATE DATABASE rteval ENCODING 'utf-8';
 -- /rteval/loads and /rteval/cyclictest/command_line
 --
     CREATE TABLE rtevalruns_details (
-        rterid          INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
-        annotation      TEXT,
-        num_cpu_cores   INTEGER,
-        num_cpu_sockets INTEGER,
-        cpu_core_spread INTEGER[],
-        numa_nodes      INTEGER,
-        xmldata         xml NOT NULL,
+        rterid        INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
+        xmldata       xml NOT NULL,
         PRIMARY KEY(rterid)
     );
     GRANT INSERT ON rtevalruns_details TO rtevparser;
@@ -153,8 +136,6 @@ CREATE DATABASE rteval ENCODING 'utf-8';
         range         REAL NOT NULL,
         median        REAL NOT NULL,
         stddev        REAL NOT NULL,
-	mean_abs_dev  REAL NOT NULL,
-	variance      REAL NOT NULL,
         cstid         SERIAL NOT NULL, -- unique record ID
         PRIMARY KEY(cstid)
     ) WITH OIDS;
@@ -192,34 +173,8 @@ CREATE DATABASE rteval ENCODING 'utf-8';
 
     GRANT INSERT ON cyclic_rawdata TO rtevparser;
 
--- TABLE: hwlatdetect_summary
--- Tracks hwlatdetect results for a particular hardware
---
-   CREATE TABLE hwlatdetect_summary (
-       rterid         INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
-       duration       INTEGER NOT NULL,
-       threshold      INTEGER NOT NULL,
-       timewindow     INTEGER NOT NULL,
-       width          INTEGER NOT NULL,
-       samplecount    INTEGER NOT NULL,
-       hwlat_min      REAL NOT NULL,
-       hwlat_avg      REAL NOT NULL,
-       hwlat_max      REAL NOT NULL
-   ) WITHOUT OIDS;
-   GRANT SELECT, INSERT ON hwlatdetect_summary TO rtevparser;
-
--- TABLE: hwlatdetect_samples
--- Contains the hwlatdetect sample records from a particular run
---
-   CREATE TABLE hwlatdetect_samples (
-       rterid         INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
-       timestamp      NUMERIC(20,10) NOT NULL,
-       latency        REAL NOT NULL
-   ) WITHOUT OIDS;
-   GRANT SELECT, INSERT ON hwlatdetect_samples TO rtevparser;
-
 -- TABLE: notes
--- This table is purely to make notes, connected to different
+-- This table is purely to make notes, connected to different 
 -- records in the database
 --
     CREATE TABLE notes (
